@@ -12,7 +12,9 @@ class Instance(int, enum.Enum):
 
     # dungeons
     ALGETHAR_ACADEMY = 1201
+    BRACKENHIDE_HOLLOW = 1196
     COURT_OF_STARS = 800
+    HALLS_OF_INFUSION = 1204
     HALLS_OF_VALOR = 721
     NELTHARUS = 1199
     RUBY_LIFE_POOLS = 1202
@@ -20,9 +22,16 @@ class Instance(int, enum.Enum):
     TEMPLE_OF_THE_JADE_SERPENT = 313
     THE_AZURE_VAULT = 1203
     THE_NOKHUD_OFFENSIVE = 1198
+    ULDAMAN_LEGACY_OF_TYR = 1197
+
+    FREEHOLD = 1001
+    NELTHARIONS_LAIR = 767
+    THE_UNDERROT = 1022
+    VORTEX_PINNACLE = 68
 
     # raids
     VAULT_OF_THE_INCARNATES = 1200
+    ABERUS_THE_SHADOWED_CRUCIBLE = 1208
 
 
 class RaidTier(int, enum.Enum):
